import React, { Component } from 'react';
import PropTypes from 'prop-types';
import languageList from '../../utils/languages.json';
import './FilterEditor.css';

export class FilterEditor extends Component {
  static propTypes = {
    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,
    filters: PropTypes.instanceOf(Object).isRequired,
    onChange: PropTypes.func.isRequired,
  }

  constructor(props) {
    super(props);
    this.state = {
      selectedLanguage: languageList[0].code,
      currentLanguage: null,
      addName: '',
      addDropdownName: '',
      addDropdownFilterName: '',
      addConditions: [{ operator: '<=' }],
      addDropdownFilterConditions: [{ operator: '<=' }],
    };
  }

    selectLanguage = (event) => {
      this.setState({
        selectedLanguage: event.target.value,
      });
    }

    selectCurrentLanguage = (currentLanguage) => {
      this.setState({ currentLanguage });
    }

  toggleLanguage = () => {
    const { filters } = this.props;
    if (Object.keys(filters).includes(this.state.selectedLanguage)) {
      delete filters[this.state.selectedLanguage];
    } else {
      filters[this.state.selectedLanguage] = {};
      filters[this.state.selectedLanguage].toggles = [];
      filters[this.state.selectedLanguage].dropdowns = [];
    }

    this.props.onChange(filters);
  }

  addAddCondition = () => {
    const { addConditions } = this.state;
    addConditions.push({ operator: '<=' });
    this.setState({ addConditions });
  }

  addDropdownFilterAddCondition = () => {
    const { addDropdownFilterConditions } = this.state;
    addDropdownFilterConditions.push({ operator: '<=' });
    this.setState({ addDropdownFilterConditions });
  }

  addNewFilter = () => {
    const { filters } = this.props;
    const newFilter = {
      name: this.state.addName,
      conditions: JSON.parse(JSON.stringify(this.state.addConditions)),
    };
    filters[this.state.currentLanguage].toggles.push(newFilter);
    this.props.onChange(filters);
  }

  addNewDropdownFilter = (index) => {
    const { filters } = this.props;
    const newFilter = {
      name: this.state.addDropdownFilterName,
      conditions: JSON.parse(JSON.stringify(this.state.addDropdownFilterConditions)),
    };
    filters[this.state.currentLanguage].dropdowns[index].filters.push(newFilter);
    this.props.onChange(filters);
  }

  addNewDropdown = () => {
    const { filters } = this.props;
    const newFilter = {
      name: this.state.addDropdownName,
      filters: [],
    };
    filters[this.state.currentLanguage].dropdowns.push(newFilter);
    this.props.onChange(filters);
  }

  handleAddNameChange = (event) => {
    this.setState({ addName: event.target.value });
  }

  handleAddDropdownFilterNameChange = (event) => {
    this.setState({ addDropdownFilterName: event.target.value });
  }


  handleAddDropdownNameChange = (event) => {
    this.setState({ addDropdownName: event.target.value });
  }

  handleConditionChange = (value, index, field) => {
    const { addConditions } = this.state;
    addConditions[index][field] = value;
    this.setState({ addConditions });
  }

  handleDropdownFilterConditionChange = (value, index, field) => {
    const { addDropdownFilterConditions } = this.state;
    addDropdownFilterConditions[index][field] = value;
    this.setState({ addDropdownFilterConditions });
  }

  removeFilter = (index) => {
    const { filters } = this.props;
    filters[this.state.currentLanguage].toggles.splice(index, 1);
    this.props.onChange(filters);
  }

  removeDropdownFilter = (index) => {
    const { filters } = this.props;
    filters[this.state.currentLanguage].dropdowns.splice(index, 1);
    this.props.onChange(filters);
  }

  render() {
    console.log(this.props.filters);
    return (
      <div style={{ width: this.props.width, height: this.props.height }} className="filter-edit">
        <div className="filter__languages">
          <div>
            <span className="filter__language-title">
                Supported languages |
            </span>
            <select onChange={this.selectLanguage}>
              {languageList.map(language => (
                <option value={language.code}>{language.name}</option>
                ))}
            </select>
            <button onClick={this.toggleLanguage}>Toggle</button>
          </div>
          <div className="filter__language-buttons">
            {Object.keys(this.props.filters).map(language => (
              <button className={this.state.currentLanguage === language ? 'active' : ''} onClick={() => { this.selectCurrentLanguage(language); }}>{languageList.find(lang => (lang.code === language)).name}</button>
            ))}
          </div>

        </div>
        {this.state.currentLanguage &&
        <div className="filter__content">
          {this.props.filters[this.state.currentLanguage].dropdowns.map((dropdown, index) => (
            <div className="filter__card">
              <div className="filter__existing">
                <div className="filter__name">
                  {dropdown.name} <button onClick={() => this.removeDropdownFilter(index)}>X</button>
                </div>
                <div className="filter__inside-cards">
                  {dropdown.filters.map(filter => (
                    <div className="filter__card">
                      <div className="filter__existing">
                        <div className="filter__name">
                          {filter.name}
                        </div>
                        <div className="filter__existing-conditions">
                          {filter.conditions.map(condition => (
                            <div className="filter__existing-condition">
                              {`${condition.left} ${condition.operator} ${condition.right}`}
                            </div>
            ))}
                        </div>
                      </div>
                    </div>
        ))}
                </div>
                <div className="filter__addtodropdown">
                  <div className="filter__add">
                    <label htmlFor="name">
                      <input placeholder="Enter the name" type="text" id="name" value={this.state.addDropdownFilterName} onChange={this.handleAddDropdownFilterNameChange} />
                    </label>
                    <div className="filter__conditions">
                      {this.state.addDropdownFilterConditions.map((condition, i) => (
                        <div className="filter__condition">
                          <input type="text" placeholder="Left" value={condition.left} onChange={(event) => { this.handleDropdownFilterConditionChange(event.target.value, i, 'left'); }} />
                          <select onChange={(event) => { this.handleDropdownFilterConditionChange(event.target.value, i, 'operator'); }}>
                            <option selected={condition.operator === '<='} value="<=">{'<='}</option>
                            <option selected={condition.operator === '==='} value="===">===</option>
                            <option selected={condition.operator === '>='} value=">=">{'>='}</option>
                          </select>
                          <input type="text" placeholder="Right" value={condition.right} onChange={(event) => { this.handleDropdownFilterConditionChange(event.target.value, i, 'right'); }} />
                          <button onClick={this.addDropdownFilterAddCondition}>Add extra condition</button>
                        </div>
              ))}
                    </div>
                    <button className="add" onClick={() => { this.addNewDropdownFilter(index); }}>Add</button>

                  </div>
                </div>
              </div>
            </div>
        ))}
          {this.props.filters[this.state.currentLanguage].toggles.map((filter, index) => (
            <div className="filter__card">
              <div className="filter__existing">
                <div className="filter__name">
                  {filter.name} <button onClick={() => this.removeFilter(index)}>X</button>
                </div>
                <div className="filter__existing-conditions">
                  {filter.conditions.map(condition => (
                    <div className="filter__existing-condition">
                      {`${condition.left} ${condition.operator} ${condition.right}`}
                    </div>
            ))}
                </div>
              </div>
            </div>
        ))}
          <div className="filter__card">
            <div className="filter__add">
              <label htmlFor="dropdownname">
                <input placeholder="Enter the dropdown name" type="text" id="dropdownname" value={this.state.addDropdownName} onChange={this.handleAddDropdownNameChange} />
              </label>
              <div>
                <button className="add" onClick={this.addNewDropdown}>Add</button>
              </div>
            </div>
          </div>
          <div className="filter__card">
            <div className="filter__add">
              <label htmlFor="name">
                <input placeholder="Enter the name" type="text" id="name" value={this.state.addName} onChange={this.handleAddNameChange} />
              </label>
              <div className="filter__conditions">
                {this.state.addConditions.map((condition, index) => (
                  <div className="filter__condition">
                    <input type="text" placeholder="Left" value={condition.left} onChange={(event) => { this.handleConditionChange(event.target.value, index, 'left'); }} />
                    <select onChange={(event) => { this.handleConditionChange(event.target.value, index, 'operator'); }}>
                      <option selected={condition.operator === '<='} value="<=">{'<='}</option>
                      <option selected={condition.operator === '==='} value="===">===</option>
                      <option selected={condition.operator === '>='} value=">=">{'>='}</option>
                    </select>
                    <input type="text" placeholder="Right" value={condition.right} onChange={(event) => { this.handleConditionChange(event.target.value, index, 'right'); }} />
                    <button onClick={this.addAddCondition}>Add extra condition</button>
                  </div>
              ))}
              </div>
              <button className="add" onClick={this.addNewFilter}>Add</button>

            </div>
          </div>
        </div>
        }


      </div>
    );
  }
}

export default FilterEditor;

