import React, { Component } from 'react';
import PropTypes from 'prop-types';
import languageList from '../../utils/languages.json';
import './TooltipEditor.css';

export class TooltipEditor extends Component {
  static propTypes = {
    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,
    object: PropTypes.instanceOf(Object).isRequired,
    onChange: PropTypes.func.isRequired,
  }

  constructor(props) {
    super(props);
    this.state = {
      selectedLanguage: languageList[0].code,
      currentLanguage: null,
    };
  }

  selectLanguage = (event) => {
    this.setState({
      selectedLanguage: event.target.value,
    });
  }

  selectCurrentLanguage = (currentLanguage) => {
    this.setState({ currentLanguage });
  }

  toggleLanguage = () => {
    const { object } = this.props;
    const { tooltip } = object;
    if (Object.keys(tooltip).includes(this.state.selectedLanguage)) {
      delete tooltip[this.state.selectedLanguage];
    } else {
      tooltip[this.state.selectedLanguage] = {};
    }
    object.tooltip = tooltip;
    this.props.onChange(object);
  }

  handleDataChange = (value, field) => {
    const { object } = this.props;
    const { tooltip } = object;
    tooltip[field] = value;
    object.tooltip = tooltip;
    this.props.onChange(object);
  }

  handleLanguageDataChange = (value, field) => {
    const { object } = this.props;
    const { tooltip } = object;
    tooltip[this.state.currentLanguage][field] = value;
    object.tooltip = tooltip;
    this.props.onChange(object);
  }

  render() {
    return (
      <div style={{ width: this.props.width, height: this.props.height }} className="tooltip-edit">
        <div className="tooltip__languages">
          <div>
            <span className="tooltip__language-title">
                Supported languages |
            </span>
            <select onChange={this.selectLanguage}>
              {languageList.map(language => (
                <option value={language.code}>{language.name}</option>
                ))}
            </select>
            <button onClick={this.toggleLanguage}>Toggle</button>
          </div>
          <div className="tooltip__language-buttons">
            {Object.keys(this.props.object.tooltip).filter(key => (languageList.find(lang => lang.code === key))).map(language => (
              <button className={this.state.currentLanguage === language ? 'active' : ''} onClick={() => { this.selectCurrentLanguage(language); }}>{languageList.find(lang => (lang.code === language)).name}</button>
        ))}
          </div>

        </div>
        <div className="tooltip__content">
          <div className="tooltip__col">
            <div className="tooltip__image">
              <div className="tooltip__image-holder">
                {this.props.object.tooltip.imageUrl ?
                  <img src={this.props.object.tooltip.imageUrl || ''} alt="map object" />
                   :
                  <div className="tooltip__image-placeholder" />}
              </div>
              <div className="tooltip__image-holder logo">
                {this.props.object.tooltip.logoUrl ?
                  <img src={this.props.object.tooltip.logoUrl || ''} alt="map object" />
                   :
                  <div className="tooltip__image-placeholder" />}
              </div>
            </div>
            <div className="tooltip__inputs">
              <label htmlFor="imageurl">Image url
                <input id="imageurl" onChange={(event) => { this.handleDataChange(event.target.value, 'imageUrl'); }} type="text" value={this.props.object.tooltip.imageUrl} placeholder="Enter the image URL" />
              </label>
              <label htmlFor="logourl">Logo url
                <input id="logourl" onChange={(event) => { this.handleDataChange(event.target.value, 'logoUrl'); }} type="text" value={this.props.object.tooltip.logoUrl} placeholder="Enter the logo URL" />
              </label>
              <label htmlFor="detailslogourl">Details logo url
                <input id="detailslogourl" onChange={(event) => { this.handleDataChange(event.target.value, 'detailsLogoUrl'); }} type="text" value={this.props.object.tooltip.detailsLogoUrl} placeholder="Enter the details logo URL" />
              </label>
              <label htmlFor="length">Length
                <input id="length" onChange={(event) => { this.handleDataChange(event.target.value, 'length'); }} type="text" value={this.props.object.tooltip.length} placeholder="Enter the length in meters" />
              </label>
              <label htmlFor="height">Height
                <input id="height" onChange={(event) => { this.handleDataChange(event.target.value, 'height'); }} type="text" value={this.props.object.tooltip.height} placeholder="Enter the height in meters" />
              </label>
              <label htmlFor="duration">Ski duration
                <input id="duration" onChange={(event) => { this.handleDataChange(event.target.value, 'duration'); }} type="text" value={this.props.object.tooltip.duration} placeholder="Enter the duration in minutes" />
              </label>
              <label htmlFor="liftduration">Lift duration
                <input id="liftduration" onChange={(event) => { this.handleDataChange(event.target.value, 'liftDuration'); }} type="text" value={this.props.object.tooltip.liftDuration} placeholder="Enter the lift duration in minutes" />
              </label>
            </div>
          </div>
          {this.state.currentLanguage &&
          <div className="tooltip__col second">
            <div className="tooltip__inputs">
              <label htmlFor="name">Name
                <input id="name" onChange={(event) => { this.handleLanguageDataChange(event.target.value, 'name'); }} type="text" value={this.props.object.tooltip[this.state.currentLanguage].name || ''} placeholder="Enter the name" />
              </label>
              <label htmlFor="type">Type
                <input id="type" onChange={(event) => { this.handleLanguageDataChange(event.target.value, 'type'); }} type="text" value={this.props.object.tooltip[this.state.currentLanguage].type || ''} placeholder="Enter the type" />
              </label>
              <label htmlFor="lifttype">Lift type
                <input id="lifttype" onChange={(event) => { this.handleLanguageDataChange(event.target.value, 'liftType'); }} type="text" value={this.props.object.tooltip[this.state.currentLanguage].liftType || ''} placeholder="Enter the lift type" />
              </label>
              <label htmlFor="description">Description
                <textarea id="description" onChange={(event) => { this.handleLanguageDataChange(event.target.value, 'description'); }} type="text" value={this.props.object.tooltip[this.state.currentLanguage].description || ''} placeholder="Enter the description" />
              </label>
            </div>
          </div>
          }

        </div>
      </div>

    );
  }
}

export default TooltipEditor;

